@@ -1,12 +1,13 @@
 <?php
+
 /**
- * Arabic language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Mostafa Hussein <mostafa@gmail.com>
  * @author Yaman Hokan <always.smile.yh@hotmail.com>
  * @author Usama Akkad <uahello@gmail.com>
  * @author uahello@gmail.com
+ * @author Ahmad Abd-Elghany <tolpa1@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -50,6 +51,7 @@ $lang['btn_revert']            = 'استعد';
 $lang['btn_register']          = 'سجّل';
 $lang['btn_apply']             = 'طبق';
 $lang['btn_media']             = 'مدير الوسائط';
+$lang['btn_deleteuser']        = 'احذف حسابي الخاص';
 $lang['loggedinas']            = 'داخل باسم';
 $lang['user']                  = 'اسم المستخدم';
 $lang['pass']                  = 'كلمة السر';
@@ -61,6 +63,7 @@ $lang['fullname']              = 'الاسم الحقيقي';
 $lang['email']                 = 'البريد الإلكتروني';
 $lang['profile']               = 'الملف الشخصي';
 $lang['badlogin']              = 'عذرا، اسم المشترك أو كلمة السر غير صحيحة';
+$lang['badpassconfirm']        = 'عذراً,كلمة السر غير صحيحة';
 $lang['minoredit']             = 'تعديلات طفيفة';
 $lang['draftdate']             = 'حفظ المسودات آليا مفعّل';
 $lang['nosecedit']             = 'غُيرت الصفحة في هذه الأثناء، معلومات الجزء اصبحت قديمة. حُمُلت كل الصفحة بدلا.';
@@ -77,6 +80,11 @@ $lang['profna']                = 'هذه الويكي لا تدعم تعديل 
 $lang['profnochange']          = 'لا تغييرات، لا شيء ليُعمل.';
 $lang['profnoempty']           = 'غير مسموح باسم مستخدم أو بريد فارغ.';
 $lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
+$lang['profnodelete']          = 'هذه الموسوعه لا ندعم حذف الأشخاص';
+$lang['profdeleteuser']        = 'احذف حساب';
+$lang['profdeleted']           = 'حسابك الخاص تم حذفه من هذه الموسوعة';
+$lang['profconfdelete']        = 'أنا أرغب في حذف حسابي من هذه الموسوعة.<br/> 
+هذا الحدث غير ممكن.';
 $lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
 $lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
 $lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
@@ -258,7 +266,6 @@ $lang['subscr_m_unsubscribe']  = 'ألغ الاشتراك';
 $lang['subscr_m_subscribe']    = 'اشترك';
 $lang['subscr_m_receive']      = 'استقبال';
 $lang['subscr_style_every']    = 'بريدا على كل تغيير';
-$lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
 $lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
 $lang['authpwdexpire']         = 'ستنتهي صلاحية كلمة السر في %d . عليك بتغييرها سريعا.';
 $lang['i_chooselang']          = 'اختر لغتك';
