@@ -21,7 +21,7 @@ $lang['apostrophe']            = '\'';
 $lang['btn_edit']              = 'Editează această pagină';
 $lang['btn_source']            = 'Arată sursa paginii';
 $lang['btn_show']              = 'Arată pagina';
-$lang['btn_create']            = 'Crează această pagină';
+$lang['btn_create']            = 'Creează această pagină';
 $lang['btn_search']            = 'Caută';
 $lang['btn_save']              = 'Salvează';
 $lang['btn_preview']           = 'Previzualizează';
@@ -34,18 +34,18 @@ $lang['btn_upload']            = 'Upload';
 $lang['btn_cancel']            = 'Renunțare';
 $lang['btn_index']             = 'Index';
 $lang['btn_secedit']           = 'Editează';
-$lang['btn_login']             = 'Login';
-$lang['btn_logout']            = 'Logout';
-$lang['btn_admin']             = 'Admin';
+$lang['btn_login']             = 'Autentificare';
+$lang['btn_logout']            = 'Deconectare';
+$lang['btn_admin']             = 'Administrativ';
 $lang['btn_update']            = 'Actualizează';
 $lang['btn_delete']            = 'Șterge';
 $lang['btn_back']              = 'Înapoi';
 $lang['btn_backlink']          = 'Legătură anterioară';
-$lang['btn_backtomedia']       = 'Înapoi la Selecția Mediafile';
-$lang['btn_subscribe']         = 'Subscrie Modificarea Paginii';
-$lang['btn_profile']           = 'Actualizează Profil';
+$lang['btn_backtomedia']       = 'Înapoi la selecția mediafile';
+$lang['btn_subscribe']         = 'Subscrie modificarea paginii';
+$lang['btn_profile']           = 'Actualizează profil';
 $lang['btn_reset']             = 'Resetează';
-$lang['btn_resendpwd']         = 'Setează o parolă nouă';
+$lang['btn_resendpwd']         = 'Configurează o parolă nouă';
 $lang['btn_draft']             = 'Editează schiță';
 $lang['btn_recover']           = 'Recuperează schiță';
 $lang['btn_draftdel']          = 'Șterge schiță';
@@ -58,51 +58,51 @@ $lang['user']                  = 'Utilizator';
 $lang['pass']                  = 'Parola';
 $lang['newpass']               = 'Parola nouă';
 $lang['oldpass']               = 'Confirmă parola curentă';
-$lang['passchk']               = 'încă o dată';
+$lang['passchk']               = 'Încă o dată';
 $lang['remember']              = 'Ține-mă minte';
 $lang['fullname']              = 'Nume complet';
-$lang['email']                 = 'E-Mail';
-$lang['profile']               = 'Profil Utilizator';
-$lang['badlogin']              = 'Imi pare rău, utilizatorul și/sau parola au fost greșite.';
-$lang['minoredit']             = 'Modificare Minoră';
+$lang['email']                 = 'E-mail';
+$lang['profile']               = 'Profil utilizator';
+$lang['badlogin']              = 'Ne pare rău, utilizatorul și/sau parola au fost greșite.';
+$lang['minoredit']             = 'Modificare minoră';
 $lang['draftdate']             = 'Schiță salvată automat la';
 $lang['nosecedit']             = 'Pagina s-a modificat între timp, secțiunea info a expirat, s-a încărcat pagina întreagă în loc.';
 $lang['regmissing']            = 'Ne pare rău, trebuie să completezi toate cîmpurile.';
-$lang['reguexists']            = 'Ne pare rău, un utilizator cu acest nume există deja logat.';
-$lang['regsuccess']            = 'Utilizatorul a fost creat. Parola a fost trimisă prin email.';
+$lang['reguexists']            = 'Ne pare rău, un utilizator cu acest nume este deja autentificat.';
+$lang['regsuccess']            = 'Utilizatorul a fost creat. Parola a fost trimisă prin e-mail.';
 $lang['regsuccess2']           = 'Utilizatorul a fost creat.';
-$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin email. Contactați administratorul!';
-$lang['regbadmail']            = 'Adresa de email este invalidă - dacă credeți că este o eroare contactați administratorul.';
+$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin e-mail. Contactează administratorul!';
+$lang['regbadmail']            = 'Adresa de e-mail este nevalidă - dacă sunteți de părere că este o eroare contactează administratorul.';
 $lang['regbadpass']            = 'Cele două parole furnizate nu sunt identice; încercați din nou.';
 $lang['regpwmail']             = 'Parola ta DokuWiki';
-$lang['reghere']               = 'Înca nu ai un cont? Fă-ți unul';
-$lang['profna']                = 'Această wiki nu suportă modificarea profilului';
+$lang['reghere']               = 'Înca nu ai un cont? Fă-ți unul!';
+$lang['profna']                = 'Acest wiki nu permite modificarea profilului';
 $lang['profnochange']          = 'Nici o modificare; nimic de făcut.';
-$lang['profnoempty']           = 'Nu sunt admise numele sau adresa de email necompletate.';
-$lang['profchanged']           = 'Profilul de utilizator a fost actualizat succes.';
-$lang['pwdforget']             = 'Parola uitată? Luați una nouă';
-$lang['resendna']              = 'Această wiki nu suportă retrimiterea parolei.';
-$lang['resendpwd']             = 'Setează o parolă nouă pentru';
+$lang['profnoempty']           = 'Nu sunt admise numele sau adresa de e-mail necompletate.';
+$lang['profchanged']           = 'Profilul de utilizator a fost actualizat cu succes.';
+$lang['pwdforget']             = 'Parola uitată? Obține una nouă!';
+$lang['resendna']              = 'Acest wiki nu permite retrimiterea parolei.';
+$lang['resendpwd']             = 'Configurează o parolă nouă pentru';
 $lang['resendpwdmissing']      = 'Ne pare rău, trebuie completate toate câmpurile.';
 $lang['resendpwdnouser']       = 'Ne pare rău, acest utilizator nu poate fi găsit în baza de date.';
-$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificați dacă ați folosit tot link-ul de confirmare.';
-$lang['resendpwdconfirm']      = 'Un link de confirmare a fost trimis prin email.';
-$lang['resendpwdsuccess']      = 'Parola nouă';
+$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verifică dacă ai folosit întreg link-ul de confirmare.';
+$lang['resendpwdconfirm']      = 'Un link de confirmare a fost trimis prin e-mail.';
+$lang['resendpwdsuccess']      = 'Noua parolă a fost trimisă prin e-mail.';
 $lang['license']               = 'Exceptând locurile unde este altfel specificat, conținutul acestui wiki este licențiat sub următoarea licență:';
-$lang['licenseok']             = 'Notă: Prin editarea acestei pagini sunteți de acord să vă licențiați conțintul sub următoarea licență:';
+$lang['licenseok']             = 'Notă: Prin editarea acestei pagini ești de acord să publici conțintul sub următoarea licență:';
 $lang['searchmedia']           = 'Caută numele fișierului:';
 $lang['searchmedia_in']        = 'Caută în %s';
-$lang['txt_upload']            = 'Selectează fisierul de încărcat';
+$lang['txt_upload']            = 'Selectează fișierul de încărcat';
 $lang['txt_filename']          = 'Încarcă fișierul ca (opțional)';
 $lang['txt_overwrt']           = 'Suprascrie fișierul existent';
 $lang['lockedby']              = 'Momentan blocat de';
 $lang['lockexpire']            = 'Blocarea expiră la';
 $lang['js']['willexpire']      = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele folosește butonul de previzualizare pentru resetarea blocării.';
-$lang['js']['notsavedyet']     = 'Există modificări nesalvate, care se vor pierde.
+$lang['js']['notsavedyet']     = 'Există modificări nesalvate care se vor pierde.
 Dorești să continui?';
 $lang['js']['searchmedia']     = 'Caută fișiere';
 $lang['js']['keepopen']        = 'Menține fereastra deschisă la selecție';
-$lang['js']['hidedetails']     = 'Ascunde Detalii';
+$lang['js']['hidedetails']     = 'Ascunde detalii';
 $lang['js']['mediatitle']      = 'Setări link';
 $lang['js']['mediadisplay']    = 'Tip link';
 $lang['js']['mediaalign']      = 'Aliniere';
@@ -110,26 +110,26 @@ $lang['js']['mediasize']       = 'Mărime imagine';
 $lang['js']['mediatarget']     = 'Țintă link';
 $lang['js']['mediaclose']      = 'Închide';
 $lang['js']['mediainsert']     = 'Inserează';
-$lang['js']['mediadisplayimg'] = 'Afișează imaginea.';
-$lang['js']['mediadisplaylnk'] = 'Afișează doar linkul.';
+$lang['js']['mediadisplayimg'] = 'Afișează imaginea';
+$lang['js']['mediadisplaylnk'] = 'Afișează doar linkul';
 $lang['js']['mediasmall']      = 'Versiune mică';
 $lang['js']['mediamedium']     = 'Versiune medie';
 $lang['js']['medialarge']      = 'Versiune mare';
-$lang['js']['mediaoriginal']   = 'Versiune originală';
+$lang['js']['mediaoriginal']   = 'Versiune inițială';
 $lang['js']['medialnk']        = 'Link către pagina detaliilor';
-$lang['js']['mediadirect']     = 'Link direct către original';
+$lang['js']['mediadirect']     = 'Link direct către versiunea inițială';
 $lang['js']['medianolnk']      = 'Fără link';
 $lang['js']['medianolink']     = 'Nu crea link către imagine';
-$lang['js']['medialeft']       = 'Aliniază imaginea la stânga.';
-$lang['js']['mediaright']      = 'Aliniază imaginea la dreapta.';
-$lang['js']['mediacenter']     = 'Aliniază imaginea la centru.';
-$lang['js']['medianoalign']    = 'Nu utiliza aliniere.';
-$lang['js']['nosmblinks']      = 'Legăturile către sharing-uri Windows funcționeaza numai in Microsoft Internet Explorer.
-Puteți însă copia și insera legătura.';
+$lang['js']['medialeft']       = 'Aliniază imaginea la stânga';
+$lang['js']['mediaright']      = 'Aliniază imaginea la dreapta';
+$lang['js']['mediacenter']     = 'Aliniază imaginea la centru';
+$lang['js']['medianoalign']    = 'Nu utiliza aliniere';
+$lang['js']['nosmblinks']      = 'Link-urile către sharing-uri Windows funcționeaza numai în Microsoft Internet Explorer.
+Poți însă copia și insera link-ul.';
 $lang['js']['linkwiz']         = 'Asistent legătură';
 $lang['js']['linkto']          = 'Legătură la:';
-$lang['js']['del_confirm']     = 'Doriți într-adevăr ștergerea elementelor selectate?';
-$lang['js']['restore_confirm'] = 'Sunteți sigur că doriți restaurarea acestei versiuni?';
+$lang['js']['del_confirm']     = 'Ești sigur de ștergerea elementele selectate?';
+$lang['js']['restore_confirm'] = 'Ești sigur de restaurarea acestei versiuni?';
 $lang['js']['media_diff']      = 'Arată diferențele:';
 $lang['js']['media_diff_both'] = 'Unul lângă altul';
 $lang['js']['media_diff_opacity'] = 'Străveziu';
@@ -138,40 +138,40 @@ $lang['js']['media_select']    = 'Selectează fișierele...';
 $lang['js']['media_upload_btn'] = 'Încarcă';
 $lang['js']['media_done_btn']  = 'Gata';
 $lang['js']['media_drop']      = 'Lasă fișierele aici pentru încărcarea lor';
-$lang['js']['media_cancel']    = 'înlătură';
+$lang['js']['media_cancel']    = 'Înlătură';
 $lang['js']['media_overwrt']   = 'Suprascrie fișierele deja existente';
-$lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui cîmp: ';
+$lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui câmp: ';
 $lang['nothingfound']          = 'Nu am găsit nimic.';
-$lang['mediaselect']           = 'Selectare fișiere media';
-$lang['fileupload']            = 'Încarcă fișier media';
+$lang['mediaselect']           = 'Fișiere media';
+$lang['fileupload']            = 'Încarcare fișier media';
 $lang['uploadsucc']            = 'Încărcare reușită';
 $lang['uploadfail']            = 'Încărcare eșuată. Poate din cauza permisiunilor?';
 $lang['uploadwrong']           = 'Încărcare nepermisă. Extensia fișierului e nepermisă';
 $lang['uploadexist']           = 'Fișierul există deja. Nimic nu a fost făcut.';
 $lang['uploadbadcontent']      = 'Conținutul încărcat nu corespunde extensiei fișierului %s.';
-$lang['uploadspam']            = 'Încărcarea a fost blocată datorită listei negre de spam.';
-$lang['uploadxss']             = 'Încărcarea a fost blocată datorită unui posibil conținut dăunător.';
+$lang['uploadspam']            = 'Încărcarea a fost blocată din cauza listei negre de spam.';
+$lang['uploadxss']             = 'Încărcarea a fost blocată din cauza unui posibil conținut dăunător.';
 $lang['uploadsize']            = 'Fișierul uploadat a fost prea mare. (max %s)';
 $lang['deletesucc']            = 'Fișierul "%s" a fost șters.';
-$lang['deletefail']            = '"%s" nu a putut fi șters - verificați drepturile.';
+$lang['deletefail']            = '"%s" nu a putut fi șters - verifică permisiunile.';
 $lang['mediainuse']            = 'Fișierul "%s" nu a fost șters - este încă în uz.';
 $lang['namespaces']            = 'Spații de nume';
 $lang['mediafiles']            = 'Fișiere disponibile în';
-$lang['accessdenied']          = 'Nu vă este permis să vizualizați această pagină.';
-$lang['mediausage']            = 'Folosiți următoarea sintaxă pentru a face referință la acest fișier:';
-$lang['mediaview']             = 'Vizualizează fișierul original';
+$lang['accessdenied']          = 'Nu îți este permis să vizualizezi această pagină.';
+$lang['mediausage']            = 'Folosește următoarea sintaxă pentru a face referință la acest fișier:';
+$lang['mediaview']             = 'Vizualizează fișierul inițial';
 $lang['mediaroot']             = 'root';
 $lang['mediaupload']           = 'Încarcă un fișier in acest spațiu de nume. Pentru a crea sub-spații de nume, adaugă-le la fișierul de încărcat, separate de doua puncte (:).';
-$lang['mediaextchange']        = 'Extensia fișierului a fost modificată din .%s în .%s!';
+$lang['mediaextchange']        = 'Extensia fișierului a fost modificată din .%s în .%s.';
 $lang['reference']             = 'Referință pentru';
-$lang['ref_inuse']             = 'Fișierul nu a putut fi șters întrucât este folosit încă de următoarele pagini:';
-$lang['ref_hidden']            = 'Nu aveți permisiunea să citiți o parte din referințele din pagină.';
-$lang['hits']                  = 'Hituri';
+$lang['ref_inuse']             = 'Fișierul nu a putut fi șters întrucât este folosit de următoarele pagini:';
+$lang['ref_hidden']            = 'Nu ai permisiunea să citești o parte din referințele din pagină.';
+$lang['hits']                  = 'Accese';
 $lang['quickhits']             = 'Nume de pagini potrivite';
 $lang['toc']                   = 'Cuprins';
 $lang['current']               = 'curent';
 $lang['yours']                 = 'Versiunea ta';
-$lang['diff']                  = 'arată diferențele față de versiunea curentă';
+$lang['diff']                  = 'Arată diferențele față de versiunea curentă';
 $lang['diff2']                 = 'Arată diferențele dintre versiunile selectate';
 $lang['difflink']              = 'Link către această vizualizare comparativă';
 $lang['diff_type']             = 'Vezi diferențe:';
@@ -179,7 +179,7 @@ $lang['diff_inline']           = 'Succesiv';
 $lang['diff_side']             = 'Alăturate';
 $lang['line']                  = 'Linia';
 $lang['breadcrumb']            = 'Traseu';
-$lang['youarehere']            = 'Sunteți aici';
+$lang['youarehere']            = 'Ești aici';
 $lang['lastmod']               = 'Ultima modificare';
 $lang['by']                    = 'de către';
 $lang['deleted']               = 'șters';
@@ -191,11 +191,11 @@ $lang['noflash']               = 'Plugin-ul <a href="http://www.adobe.com/produc
 $lang['download']              = 'Bloc descărcări';
 $lang['tools']                 = 'Unelte';
 $lang['user_tools']            = 'Unelte utilizator';
-$lang['site_tools']            = 'Unelte Site';
-$lang['page_tools']            = 'Unelte Pagină';
-$lang['skip_to_content']       = 'sari la conținut';
-$lang['mail_newpage']          = 'pagina adăugată:';
-$lang['mail_changed']          = 'page schimbată:';
+$lang['site_tools']            = 'Unelte site';
+$lang['page_tools']            = 'Unelte pagină';
+$lang['skip_to_content']       = 'mergi la conținut';
+$lang['mail_newpage']          = 'pagină adăugată:';
+$lang['mail_changed']          = 'pagină schimbată:';
 $lang['mail_subscribe_list']   = 'pagini modificate în spațiul de nume:';
 $lang['mail_new_user']         = 'utilizator nou';
 $lang['mail_upload']           = 'fișier încărcat:';
@@ -203,43 +203,43 @@ $lang['changes_type']          = 'Vizualizare modificări';
 $lang['pages_changes']         = 'Pagini';
 $lang['media_changes']         = 'Fișiere media';
 $lang['both_changes']          = 'Ambele pagini și fișiere media';
-$lang['qb_bold']               = 'Text Îngroșat';
-$lang['qb_italic']             = 'Text Italic';
-$lang['qb_underl']             = 'Text Subliniat';
-$lang['qb_code']               = 'Text Cod';
-$lang['qb_strike']             = 'Text Tăiat';
-$lang['qb_h1']                 = 'Titlu de Nivel 1';
-$lang['qb_h2']                 = 'Titlu de Nivel 2';
-$lang['qb_h3']                 = 'Titlu de Nivel 3';
-$lang['qb_h4']                 = 'Titlu de Nivel 4';
-$lang['qb_h5']                 = 'Titlu de Nivel 5';
+$lang['qb_bold']               = 'Text aldin';
+$lang['qb_italic']             = 'Text cursiv';
+$lang['qb_underl']             = 'Text subliniat';
+$lang['qb_code']               = 'Text cod';
+$lang['qb_strike']             = 'Text tăiat';
+$lang['qb_h1']                 = 'Titlu de nivel 1';
+$lang['qb_h2']                 = 'Titlu de nivel 2';
+$lang['qb_h3']                 = 'Titlu de nivel 3';
+$lang['qb_h4']                 = 'Titlu de nivel 4';
+$lang['qb_h5']                 = 'Titlu de nivel 5';
 $lang['qb_h']                  = 'Titlu';
-$lang['qb_hs']                 = 'Selectați Titlul';
+$lang['qb_hs']                 = 'Selectează titlul';
 $lang['qb_hplus']              = 'Titlu mai mare';
 $lang['qb_hminus']             = 'Titlu mai mic';
 $lang['qb_hequal']             = 'Titlu de același nivel';
-$lang['qb_link']               = 'Legătură internă';
-$lang['qb_extlink']            = 'Legătura externă';
-$lang['qb_hr']                 = 'Linie Orizontal';
-$lang['qb_ol']                 = 'Listă Ordonată';
-$lang['qb_ul']                 = 'Listă Neordoată';
+$lang['qb_link']               = 'Link intern';
+$lang['qb_extlink']            = 'Link extern';
+$lang['qb_hr']                 = 'Linie orizontală';
+$lang['qb_ol']                 = 'Listă ordonată';
+$lang['qb_ul']                 = 'Listă neordoată';
 $lang['qb_media']              = 'Adaugă imagini și alte fișiere';
 $lang['qb_sig']                = 'Inserează semnătură';
 $lang['qb_smileys']            = 'Smiley-uri';
 $lang['qb_chars']              = 'Caractere speciale';
-$lang['upperns']               = 'sari la numele de spațiu părinte';
+$lang['upperns']               = 'Accesează spațiul de nume părinte';
 $lang['admin_register']        = 'Adaugă utilizator nou';
-$lang['metaedit']              = 'Editează Metadata';
+$lang['metaedit']              = 'Editează metadata';
 $lang['metasaveerr']           = 'Scrierea metadatelor a eșuat';
 $lang['metasaveok']            = 'Metadatele au fost salvate';
 $lang['img_backto']            = 'Înapoi la';
 $lang['img_title']             = 'Titlu';
 $lang['img_caption']           = 'Legendă';
-$lang['img_date']              = 'Data';
+$lang['img_date']              = 'Dată';
 $lang['img_fname']             = 'Nume fișier';
 $lang['img_fsize']             = 'Dimensiune';
 $lang['img_artist']            = 'Fotograf';
-$lang['img_copyr']             = 'Copyright';
+$lang['img_copyr']             = 'Drept de autor';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Cuvinte cheie';
@@ -248,47 +248,46 @@ $lang['img_height']            = 'Înălțime';
 $lang['img_manager']           = 'Vizualizează în administratorul media';
 $lang['subscr_subscribe_success'] = 'Adăugat %s la lista de abonare pentru %s';
 $lang['subscr_subscribe_error'] = 'Eroare la adăugarea %s la lista de abonare pentru %s';
-$lang['subscr_subscribe_noaddress'] = 'Nu există adresa asociată cu logarea dvs., nu puteți fi adăugat la lista de abonare';
+$lang['subscr_subscribe_noaddress'] = 'Nu există adresă de e-mail asociată autentificării curente, nu poți fi adăugat la lista de abonare';
 $lang['subscr_unsubscribe_success'] = 'Șters %s din lista de abonare pentru %s';
 $lang['subscr_unsubscribe_error'] = 'Eroare la ștergerea %s din lista de abonare pentru %s';
 $lang['subscr_already_subscribed'] = '%s este deja abonat la %s';
 $lang['subscr_not_subscribed'] = '%s nu este abonat la %s';
-$lang['subscr_m_not_subscribed'] = 'Momentan nu sunteți abonat la pagina curentă sau la numele de spațiu.';
+$lang['subscr_m_not_subscribed'] = 'Momentan nu ești abonat la pagina curentă sau la spațiul de nume.';
 $lang['subscr_m_new_header']   = 'Adaugă abonare';
 $lang['subscr_m_current_header'] = 'Abonări curente';
-$lang['subscr_m_unsubscribe']  = 'Dezabonați-vă';
-$lang['subscr_m_subscribe']    = 'Abonați-vă';
-$lang['subscr_m_receive']      = 'Primiți';
-$lang['subscr_style_every']    = 'email la ficare schimbare';
-$lang['subscr_style_digest']   = 'digerează email la schimbări pentru fiecare pagină (la fiecare %.2f zile)';
-$lang['subscr_style_list']     = 'lista paginilor schimbate de la ultimul email (la fiecare %.2f zile)';
-$lang['authmodfailed']         = 'Configurația autentificării utilizatorului este eronată. Anunțați Wiki Admin-ul.';
-$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunțați Wiki Admin-ul.';
-$lang['authpwdexpire']         = 'Parola vă va expira în %d zile, ar trebui să o schimbați curând.';
-$lang['i_chooselang']          = 'Alegeți limba';
-$lang['i_installer']           = 'DokuWiki Installer';
-$lang['i_wikiname']            = 'Numele Wiki';
-$lang['i_enableacl']           = 'Activează ACL (recomandat)';
-$lang['i_superuser']           = 'Superutilizator';
-$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu puteți continua până nu le rezolvați.';
-$lang['i_modified']            = 'Din motive de securitate, acest script va funcționa doar cu o instalare nouă și nemodificată a Docuwiki.
-Puteți fie să extrageți din nou fișierele din arhiva descărcată fie să consultați instrucțiunile de instalare Dokuwiki la <a href="http://dokuwiki.org/install">';
-$lang['i_funcna']              = 'Funcția PHP <code>%s</code> nu este disponibilă. Probabil provider-ul dvs. a inactivat-o pentru un motiv oarecare.';
-$lang['i_phpver']              = 'Versiunea dvs. de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să vă actualizați instalarea PHP.';
-$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modificați drepturile acestui director!';
+$lang['subscr_m_unsubscribe']  = 'Dezabonează-te';
+$lang['subscr_m_subscribe']    = 'Abonează-te';
+$lang['subscr_m_receive']      = 'Primește';
+$lang['subscr_style_every']    = 'e-mail la ficare schimbare';
+$lang['subscr_style_digest']   = 'e-mail cu sumar al modificărilor pentru fiecare pagină (la fiecare %.2f zile)';
+$lang['subscr_style_list']     = 'lista paginilor modificate de la ultimul e-mail (la fiecare %.2f zile)';
+$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Contactează administratorul.';
+$lang['authpwdexpire']         = 'Parola va expira în %d zile, ar trebui să o schimbi în curând.';
+$lang['i_chooselang']          = 'Alege limba';
+$lang['i_installer']           = 'Installer DokuWiki';
+$lang['i_wikiname']            = 'Numele acestui wiki';
+$lang['i_enableacl']           = 'Activează ACL (liste de control a accesului) (recomandat)';
+$lang['i_superuser']           = 'Utilizator privilegiat';
+$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu poți continua până nu le rezolvi.';
+$lang['i_modified']            = 'Din motive de securitate, acest script va funcționa doar cu o instalare nouă și nemodificată a DokuWiki.
+Poți fie să extragi din nou fișierele din arhiva descărcată fie să consulți instrucțiunile de instalare DokuWiki la <a href="http://dokuwiki.org/install">';
+$lang['i_funcna']              = 'Funcția PHP <code>%s</code> nu este disponibilă. Probabil provider-ul tău a dezactivat-o pentru un motiv anume.';
+$lang['i_phpver']              = 'Versiunea ta de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să îți actualizezi instalarea PHP.';
+$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modifici permisiunile pe acest director.';
 $lang['i_confexists']          = '<code>%s</code> există deja';
-$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verificați drepturile directorului/fișierului și să creați fișierul manual.';
+$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verifici permisiunile directorului/fișierului și să creezi fișierul manual.';
 $lang['i_badhash']             = 'dokuwiki.php nu a fost recunoscut sau a fost modificat (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valoare nepemisă sau neintrodusă';
-$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum puteți sterge fișierul install.php. Continuați cu <a href="doku.php?id=wiki:welcome">your new DokuWiki</a>.';
-$lang['i_failure']             = 'Au apărut erori la scrierea fișierelor de configurare. Va trebui să le corectați manual înainte de a putea folosi <a href="doku.php?id=wiki:welcome">your new DokuWiki</a>.';
-$lang['i_policy']              = 'Politica ACL inițială';
-$lang['i_pol0']                = 'Wiki Deschisă (citește, scrie și încarcă oricine)';
-$lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie și încarcă doar utilizatorul înregistrat)';
-$lang['i_pol2']                = 'Wiki Închisă (citește, scrie și încarcă doar utilizatorul înregistrat)';
+$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum poți sterge fișierul install.php. Poți accesa <a href="doku.php?id=wiki:welcome">noua ta instanță DokuWiki</a>.';
+$lang['i_failure']             = 'Au apărut erori la scrierea fișierelor de configurare. Va trebui să le corectezi manual înainte de a putea folosi <a href="doku.php?id=wiki:welcome">noua ta instanță DokuWiki</a>.';
+$lang['i_policy']              = 'Politica ACL (liste de control a accesului) inițială';
+$lang['i_pol0']                = 'Wiki deschis (oricine poate citi, scrie și încărca fișiere)';
+$lang['i_pol1']                = 'Wiki public (oricine poate citi, utilizatorii înregistrați pot scrie și încărca fișiere';
+$lang['i_pol2']                = 'Wiki închis (doar utilizatorii înregistrați pot citi, scrie și încărca fișiere)';
 $lang['i_retry']               = 'Încearcă din nou';
-$lang['i_license']             = 'Vă rugăm alegeți licența sub care doriți să vă licențiați materialul:';
-$lang['recent_global']         = 'Acum vizualizați modificările în interiorul numelui de spațiu <b>%s</b>. De asemenea puteți <a href="%s">vizualiza modificările recente ale întregului wiki</a>.';
+$lang['i_license']             = 'Te rugăm să alegi licența sub care dorești să publici conținutul:';
+$lang['recent_global']         = 'În acest moment vizualizezi modificările în interiorul spațiului de nume <b>%s</b>. De asemenea poți <a href="%s">vizualiza modificările recente în întregului wiki-ul</a>.';
 $lang['years']                 = 'acum %d ani';
 $lang['months']                = 'acum %d luni';
 $lang['weeks']                 = 'acum %d săptămâni';
@@ -296,8 +295,8 @@ $lang['days']                  = 'acum %d zile';
 $lang['hours']                 = 'acum %d ore';
 $lang['minutes']               = 'acum %d minute';
 $lang['seconds']               = 'acum %d secunde';
-$lang['wordblock']             = 'Modificarea dvs. nu au fost salvate deoarece conține text blocat (spam).';
-$lang['media_uploadtab']       = 'Încarcă';
+$lang['wordblock']             = 'Modificarea ta nu a fost salvată deoarece conține text blocat (spam).';
+$lang['media_uploadtab']       = 'Încărcare fișier';
 $lang['media_searchtab']       = 'Căutare';
 $lang['media_file']            = 'Fișier';
 $lang['media_viewtab']         = 'Vizualizare';
@@ -306,17 +305,17 @@ $lang['media_historytab']      = 'Istoric';
 $lang['media_list_thumbs']     = 'Miniaturi';
 $lang['media_list_rows']       = 'Linii';
 $lang['media_sort_name']       = 'Nume';
-$lang['media_sort_date']       = 'Data';
-$lang['media_namespaces']      = 'Alegeți numele se spațiu';
+$lang['media_sort_date']       = 'Dată';
+$lang['media_namespaces']      = 'Alege spațiul de nume';
 $lang['media_files']           = 'Fișiere în %s';
-$lang['media_upload']          = 'Încarcă în %s';
-$lang['media_search']          = 'Caută în %s';
+$lang['media_upload']          = 'Încărcare în %s';
+$lang['media_search']          = 'Cautare în %s';
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s în %s';
 $lang['media_edit']            = 'Editare %s';
 $lang['media_history']         = 'Istoricul pentru %s';
 $lang['media_meta_edited']     = 'metadate editate';
-$lang['media_perm_read']       = 'Ne pare rău, dar nu aveți suficiente drepturi pentru a putea citi fișiere.';
-$lang['media_perm_upload']     = 'Ne pare rău, dar nu aveți suficiente drepturi pentru a putea încărca fișiere.';
+$lang['media_perm_read']       = 'Ne pare rău, dar nu ai suficiente permisiuni pentru a putea citi fișiere.';
+$lang['media_perm_upload']     = 'Ne pare rău, dar nu ai suficiente permisiuni pentru a putea încărca fișiere.';
 $lang['media_update']          = 'Încarcă noua versiune';
 $lang['media_restore']         = 'Restaurează această versiune';
